# hexo-next-publist

[![npm version](https://badge.fury.io/js/hexo-next-publist.svg)](https://badge.fury.io/js/hexo-next-publist)
[![npm dependencies](https://david-dm.org/Aetf/hexo-next-publist.svg)](https://david-dm.org/Aetf/hexo-next-publist)
[![Build Status](https://github.com/Aetf/hexo-next-publist/workflows/Node.js%20CI/badge.svg)](https://github.com/Aetf/hexo-next-publist/actions?query=workflow%3A"Node.js+CI")

[![NPM](https://nodei.co/npm/hexo-next-publist.png)](https://npmjs.org/package/hexo-next-publist)

Show a list of publications anywhere in the markdown post. There is also a customizable panel to filter the results.

## Demo

The research page in my [my blog](https://unlimited-code.works/research) are generated by this plugin. Please go and take a look.
The source code is available on [Github](https://github.com/Aetf/Aetf.github.io).

## Installation

`npm i -S hexo-next-publist`

This will install `hexo-next-publist` and add it as a dependency in your `package.json`.

NOTE: There are also several peer dependencies you may need to install.
Follow the instruction printed when running the previous command to install the missing ones.

## Usage

### Tag usage

First of all, you need to add
```yaml
publist: true
```
to the front-matter of the post/page that you wish to use the publist tag.
For performance reasons, publist will not inject supplimentary js and css unless told to do so.

To insert publist, use the following in the post markdown source.
The content between the tags defines any conferences the bibtex file will refer.

```
{% publist mypubs %}
pub_dir: assets/pub
highlight_authors: []
# extra filters to show, they will filter on the item using given path
extra_filters:
  - name: Topic
    path: meta.topic
  - name: Tag
    path: meta.tag
  - name: Badge
    path: badges
venues:
  Conferences:
    # conference short name
    MLSys'20:
      # conference id
      venue: MLSys
      # conference full name
      name: The 3rd Conference on Machine Learning and Systems
      # date for sorting (optional. If this is missing, the year and month in bib entry will be used)
      date: 2020-03-02
      # conference website (optional)
      url: https://mlsys.org/Conferences/2020
      # conference acceptance rate (optional)
      acceptance: "19.2%"
  Workshops: {}
  Posters: {}
  Demos: {}
  Journals: {}
{% endpublist %}
```

The only argument is the name of bib file, in `source/_data` folder.

You'll need to add some publist specific fields, but they will be striped out when display.

- `publist_link`, `publist_badge`, and `publist_abstract` are optional.
- `publist_link` and `publist_badge` can be specified multiple times.
- The content in `publist_abstract` will be rendered as markdown with support for latex math. If this
field does not present, the normal `abstract` field will be used. However, in this case, the content
will be used verbatim.
- Other fields like `publist_xxx` can be added to attach metadata fields to the entry.

One subfolder following the entry key per entry, containing bibtex, abstract, pdf, and any additional files.
If the link part starts with `/`, then it is intepreted as absolute path.

`source/_data/mypub.bib`
```bibtex
@inproceedings{yu20mlsys,
    title = {{Salus}: Find-grained {GPU} Sharing primitives for Deep Learning Applications},
    author = {Yu, Peifeng and Chowdhury, Mosharaf},
    booktitle = {Proceedings of the 3rd Conference on Machine Learning and Systems},
    year = {2020},

    publist_confkey = {MLSys'20},
    publist_link = {paper || yu20mlsys.pdf},
    publist_link = {talk || yu20mlsys-talk.pptx},
    publist_link = {poster || yu20mlsys-poster.pdf},
    publist_badge = {Artifacts Available},
    publist_badge = {Artifacts Evaluated Functional},
    publist_badge = {Artifacts Replicated},
    publist_abstract = {
      This is an abstract.

      The common spaces before each line will be stripped.
    }
    publist_tag = {tagA},
    publist_tag = {tagB},
    publist_topic = {Deep Learning},
    publist_topic = {GPU},
}
```

### Configuration

#### Global options in `_config.yml`

```yaml
publist:
  # where should the publist js and css files be served
  # publist will generate its own js and css file under this prefix
  assets_prefix: assets/publist
  # entries within the last `new_months` will be marked new
  new_months: 3
  # if strict mode is enabled, any bibtex parsing errors will be fatal
  strict: false
```


## Internals

- `_config.yml` contains main options under the key `publist`.
- `src/injector.js` injects `templates/{headend,bodyend}.njk` to every page,
but the content will only be inserted if the front-matter contains `publist_enabled: true`
- `src/widget` implements a hexo box, processing all assets under `widget`, and serving them.
- `src/bib-renderer.js` reads `.bib` files under `source/_data` in the user's repo. The result will
be available as data in the data model.
- `src/publist.js` is the actual tag plugin, which reads bib data
from the data model and renders the html.
